@@ -1,14 +1,16 @@
 
 FILE=barnard-calibrated.fits
+CONE=cone_barnard.fits
 
 cp astrometry/${FILE} ${AUTOPKGTEST_TMP}
+cp astrometry/${CONE} ${AUTOPKGTEST_TMP}
 cd ${AUTOPKGTEST_TMP}
 
 munipack find -f 5 $FILE
 munipack aphot $FILE
-munipack cone -r 0.2 -- 269.5 4.6
-munipack astrometry $FILE
+# munipack cone -r 0.1 --par 'Vmag=<15' -o cone_barnard.fits -- 269.44 4.69
+munipack astrometry -c $CONE $FILE
 munipack phcal --photsys-ref Johnson --area 0.3 \
 	 --col-ra RAJ2000 --col-dec DEJ2000 \
-	 -f V --col-mag Vmag --col-magerr e_Vmag -c cone.fits \
+	 -f V --col-mag Vmag --col-magerr e_Vmag -c $CONE \
 	 -O --mask '\!\1_phcal.\2' $FILE
